# **earthaccess** API

earthaccess is a Python library that simplifies data discovery and access to NASA Earth science data by providing a higher abstraction for NASA’s Search API (CMR) so that searching for data can be done using a simpler notation instead of low level HTTP queries.

This library handles authentication with NASA’s OAuth2 API (EDL) and provides HTTP and AWS S3 sessions that can be used with xarray and other PyData libraries to access NASA EOSDIS datasets directly allowing scientists get to their science in a simpler and faster way, reducing barriers to cloud-based data analysis.


***



::: earthaccess.api
    options:
      inherited_members: true
    show_root_heading: true
    show_source: false

::: earthaccess.dmrpp_zarr
    options:
      inherited_members: true
    show_root_heading: true
    show_source: false
